@@ -40,7 +40,10 @@ from ansiblelint.constants import RC
 from ansiblelint.file_utils import Lintable, cwd
 from ansiblelint.runner import Runner
 from ansiblelint.testing import run_ansible_lint
-from ansiblelint.types import AnsibleMapping, AnsibleSequence
+from ansiblelint.types import (  # pyright: ignore[reportAttributeAccessIssue]
+    AnsibleMapping,  # pyright: ignore[reportAttributeAccessIssue]
+    AnsibleSequence,  # pyright: ignore[reportAttributeAccessIssue]
+)
 
 if TYPE_CHECKING:
     from collections.abc import Sequence
